@@ -1,6 +1,9 @@
-#' Two-way ANOVA
+#' Two-Way Factorial ANOVA
 #'
-#' Conduct a two-way analysis of variance (ANOVA).
+#' This function is deprecated. Use the function 'factorial_anova_2_way'
+#' instead.
+#'
+#' Conduct a two-way factorial analysis of variance (ANOVA).
 #'
 #' The following package(s) must be installed prior to running this function:
 #' Package 'car' v3.0.9 (or possibly a higher version) by
@@ -94,7 +97,7 @@
 #' using the \code{grid.arrange} function.
 #' @return by default, the output will be \code{"anova_table"}
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' two_way_anova(
 #'   data = mtcars, dv_name = "mpg", iv_1_name = "vs",
 #'   iv_2_name = "am", iterations = 100)
@@ -138,6 +141,10 @@ two_way_anova <- function(
   units = "px",
   res = 300,
   layout_matrix = NULL) {
+  kim::pm(
+    "Warning: The function 'two_way_anova' is deprecated.\n",
+    "Please use the function 'factorial_anova_2_way' or\n",
+    "'mixed_anova_2_way' instead.")
   # installed packages
   installed_pkgs <- rownames(utils::installed.packages())
   # check if Package 'ggplot2' is installed
